@@ -1,6 +1,6 @@
 package Silki::Formatter::WikiToHTML;
 BEGIN {
-  $Silki::Formatter::WikiToHTML::VERSION = '0.05';
+  $Silki::Formatter::WikiToHTML::VERSION = '0.06';
 }
 
 use strict;
@@ -23,6 +23,12 @@ has _user => (
     init_arg => 'user',
 );
 
+has _page => (
+    is       => 'ro',
+    isa      => 'Silki::Schema::Page',
+    init_arg => 'page',
+);
+
 has _wiki => (
     is       => 'ro',
     isa      => 'Silki::Schema::Wiki',
@@ -39,8 +45,9 @@ sub wiki_to_html {
 
     my $html = Silki::Markdent::Handler::HTMLStream->new(
         output => $fh,
-        wiki   => $self->_wiki(),
-        user   => $self->_user()
+        ( $self->_page() ? ( page => $self->_page() ) : () ),
+        wiki => $self->_wiki(),
+        user => $self->_user()
     );
 
     my $filter = Markdent::Handler::HTMLFilter->new( handler => $html );
@@ -71,7 +78,7 @@ Silki::Formatter::WikiToHTML - Turns wikitext into HTML
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 AUTHOR
 
