@@ -1,6 +1,6 @@
 package Silki::Role::Controller::User;
 BEGIN {
-  $Silki::Role::Controller::User::VERSION = '0.05';
+  $Silki::Role::Controller::User::VERSION = '0.06';
 }
 
 use strict;
@@ -51,29 +51,6 @@ after '_set_user' => sub {
         }
     );
 
-    if ( $c->user()->can_edit_user($user) ) {
-        my %prefs
-            = $c->user()->user_id() == $user->user_id()
-            ? (
-            label   => loc('Your preferences'),
-            tooltip => loc('Set your preferences'),
-            )
-            : (
-            label   => loc( 'Preferences for %1', $user->best_name() ),
-            tooltip => loc(
-                'View and change preferences for %1', $user->best_name()
-            ),
-            );
-
-        $c->add_tab(
-            {
-                uri => $self->_make_user_uri( $c, $user, 'preferences_form' ),
-                id  => 'preferences',
-                %prefs,
-            }
-        );
-    }
-
     $c->stash()->{user} = $user;
 };
 
@@ -244,8 +221,6 @@ sub preferences_form : Chained('_set_user') : PathPart('preferences_form') : Arg
     $c->redirect_and_detach( $self->_make_user_uri( $c, $user ) )
         unless $c->user()->can_edit_user($user);
 
-    $c->tab_by_id('preferences')->set_is_selected(1);
-
     $c->stash()->{template} = '/user/preferences-form';
 }
 
@@ -262,7 +237,7 @@ Silki::Role::Controller::User - Provides user-related methods and actions
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 AUTHOR
 
