@@ -1,6 +1,6 @@
 package Silki::Schema::Wiki;
 BEGIN {
-  $Silki::Schema::Wiki::VERSION = '0.05';
+  $Silki::Schema::Wiki::VERSION = '0.06';
 }
 
 use strict;
@@ -162,6 +162,34 @@ class_has _PopularTagsSelect => (
     builder => '_BuildPopularTagsSelect',
 );
 
+class_has _PagesEditedByUserSelect => (
+    is      => 'ro',
+    does    => 'Fey::Role::SQL::ReturnsData',
+    lazy    => 1,
+    builder => '_BuildPagesEditedByUserSelect',
+);
+
+class_has _PagesEditedByUserCountSelect => (
+    is      => 'ro',
+    does    => 'Fey::Role::SQL::ReturnsData',
+    lazy    => 1,
+    builder => '_BuildPagesEditedByUserCountSelect',
+);
+
+class_has _PagesCreatedByUserSelect => (
+    is      => 'ro',
+    does    => 'Fey::Role::SQL::ReturnsData',
+    lazy    => 1,
+    builder => '_BuildPagesCreatedByUserSelect',
+);
+
+class_has _PagesCreatedByUserCountSelect => (
+    is      => 'ro',
+    does    => 'Fey::Role::SQL::ReturnsData',
+    lazy    => 1,
+    builder => '_BuildPagesCreatedByUserCountSelect',
+);
+
 class_has _PublicWikiCountSelect => (
     is      => 'ro',
     isa     => 'Fey::SQL::Select',
@@ -190,6 +218,13 @@ class_has _MaxRevisionSelect => (
     builder => '_BuildMaxRevisionSelect',
 );
 
+class_has _MinRevisionSelect => (
+    is      => 'ro',
+    isa     => 'Fey::SQL::Select',
+    lazy    => 1,
+    builder => '_BuildMinRevisionSelect',
+);
+
 query revision_count => (
     select      => __PACKAGE__->_DistinctRevisionCountSelect(),
     bind_params => sub { $_[0]->wiki_id() },
@@ -369,6 +404,17 @@ sub _base_uri_path {
     return '/wiki/' . $self->short_name();
 }
 
+sub uri_for_member {
+    my $self = shift;
+    my $user = shift;
+    my $view = shift;
+
+    my $view_base = 'user/' . $user->user_id();
+    $view_base .= q{/} . $view if defined $view;
+
+    return $self->uri( view => $view_base );
+}
+
 sub add_user {
     my $self = shift;
     my ( $user, $role ) = validated_list(
@@ -1099,9 +1145,6 @@ sub text_search {
     my $page_revision_t = $Schema->table('PageRevision');
     my $pst_t = $Schema->table('PageSearchableText');
 
-    my $max_func = Fey::Literal::Function->new( 'MAX',
-        $Schema->table('PageRevision')->column('revision_number') );
-
     my $max_revision = $self->_MaxRevisionSelect();
 
     my $rank = Fey::Literal::Function->new(
@@ -1348,6 +1391,171 @@ sub _TagCountSelect {
     return $select;
 }
 
+sub pages_edited_by_user {
+    my $self = shift;
+    my ( $user, $limit, $offset ) = validated_list(
+        \@_,
+        user   => { isa => 'Silki::Schema::User' },
+        limit  => { isa => Int, optional => 1 },
+        offset => { isa => Int, default => 0 },
+    );
+
+    my $select = $self->_PagesEditedByUserSelect()->clone();
+    $select->limit( $limit, $offset );
+
+    my $dbh = Silki::Schema->DBIManager()->source_for_sql($select)->dbh();
+
+    return Fey::Object::Iterator::FromSelect->new(
+        classes     => [ 'Silki::Schema::Page', 'Silki::Schema::PageRevision' ],
+        select      => $select,
+        dbh         => $dbh,
+        bind_params => [ $self->wiki_id(), $user->user_id() ],
+    );
+}
+
+sub _BuildPagesEditedByUserSelect {
+    my $class = shift;
+
+    my $select = Silki::Schema->SQLFactoryClass()->new_select();
+
+    my $max_revision = $class->_MaxRevisionSelect();
+
+    my ( $page_t, $page_revision_t )
+        = $Schema->tables( 'Page', 'PageRevision' );
+
+    $select
+        ->select( $page_t, $page_revision_t )
+        ->from( $page_t, $page_revision_t )
+        ->where( $page_t->column('wiki_id'), '=', Fey::Placeholder->new() )
+        ->and  ( $page_revision_t->column('user_id'), '=', Fey::Placeholder->new() )
+        ->and  ( $page_revision_t->column('revision_number'),
+                 '=', $max_revision )
+        ->order_by( $page_revision_t->column('creation_datetime'), 'DESC',
+                    $page_t->column('title'), 'ASC' );
+
+    return $select;
+}
+
+sub pages_edited_by_user_count {
+    my $self = shift;
+    my ($user) = pos_validated_list( \@_, { isa => 'Silki::Schema::User' } );
+
+    my $select = $self->_PagesEditedByUserCountSelect();
+
+    my $dbh = Silki::Schema->DBIManager()->source_for_sql($select)->dbh();
+
+    my $vals = $dbh->selectrow_arrayref(
+        $select->sql($dbh),
+        {},
+        $self->wiki_id(), $user->user_id(),
+    );
+
+    return $vals ? $vals->[0] : 0;
+}
+
+sub _BuildPagesEditedByUserCountSelect {
+    my $class = shift;
+
+    my $select = Silki::Schema->SQLFactoryClass()->new_select();
+
+    my ( $page_t, $page_revision_t )
+        = $Schema->tables( 'Page', 'PageRevision' );
+
+    my $distinct = Fey::Literal::Term->new(
+        'DISTINCT ',
+        Fey::Literal::Function->new( 'COUNT', $page_revision_t->column('page_id') )
+    );
+
+    $select
+        ->select($distinct)
+        ->from( $page_t, $page_revision_t )
+        ->where( $page_t->column('wiki_id'), '=', Fey::Placeholder->new() )
+        ->and  ( $page_revision_t->column('user_id'), '=', Fey::Placeholder->new() );
+
+    return $select;
+}
+
+sub pages_created_by_user {
+    my $self = shift;
+    my ( $user, $limit, $offset ) = validated_list(
+        \@_,
+        user   => { isa => 'Silki::Schema::User' },
+        limit  => { isa => Int, optional => 1 },
+        offset => { isa => Int, default => 0 },
+    );
+
+    my $select = $self->_PagesCreatedByUserSelect()->clone();
+    $select->limit( $limit, $offset );
+
+    my $dbh = Silki::Schema->DBIManager()->source_for_sql($select)->dbh();
+
+    return Fey::Object::Iterator::FromSelect->new(
+        classes     => [ 'Silki::Schema::Page', 'Silki::Schema::PageRevision' ],
+        select      => $select,
+        dbh         => $dbh,
+        bind_params => [ $self->wiki_id(), $user->user_id() ],
+    );
+}
+
+sub _BuildPagesCreatedByUserSelect {
+    my $class = shift;
+
+    my $select = Silki::Schema->SQLFactoryClass()->new_select();
+
+    my $min_revision = $class->_MinRevisionSelect();
+
+    my ( $page_t, $page_revision_t )
+        = $Schema->tables( 'Page', 'PageRevision' );
+
+    $select
+        ->select( $page_t, $page_revision_t )
+        ->from( $page_t, $page_revision_t )
+        ->where( $page_t->column('wiki_id'), '=', Fey::Placeholder->new() )
+        ->and  ( $page_t->column('user_id'), '=', Fey::Placeholder->new() )
+        ->and  ( $page_revision_t->column('revision_number'),
+                 '=', $min_revision )
+        ->order_by( $page_revision_t->column('creation_datetime'), 'DESC',
+                    $page_t->column('title'), 'ASC' );
+
+    return $select;
+}
+
+sub pages_created_by_user_count {
+    my $self = shift;
+    my ($user) = pos_validated_list( \@_, { isa => 'Silki::Schema::User' } );
+
+    my $select = $self->_PagesCreatedByUserCountSelect();
+
+    my $dbh = Silki::Schema->DBIManager()->source_for_sql($select)->dbh();
+
+    my $vals = $dbh->selectrow_arrayref(
+        $select->sql($dbh),
+        {},
+        $self->wiki_id(), $user->user_id(),
+    );
+
+    return $vals ? $vals->[0] : 0;
+}
+
+sub _BuildPagesCreatedByUserCountSelect {
+    my $class = shift;
+
+    my $select = Silki::Schema->SQLFactoryClass()->new_select();
+
+    my $page_t = $Schema->table('Page');
+
+    my $count
+        = Fey::Literal::Function->new( 'COUNT', $page_t->column('page_id') );
+
+    $select
+        ->select($count)
+        ->from($page_t)
+        ->where( $page_t->column('wiki_id'), '=', Fey::Placeholder->new() )
+        ->and  ( $page_t->column('user_id'), '=', Fey::Placeholder->new() );
+
+    return $select;
+}
+
 sub PublicWikiCount {
     my $class = shift;
 
@@ -1480,6 +1688,28 @@ sub _BuildMaxRevisionSelect {
     return $max_revision;
 }
 
+sub _BuildMinRevisionSelect {
+    my $class = shift;
+
+    my ( $page_t, $page_revision_t )
+        = $Schema->tables( 'Page', 'PageRevision' );
+
+    my $min_func = Fey::Literal::Function->new(
+        'MIN',
+        $page_revision_t->column('revision_number'),
+    );
+
+    my $min_revision = Silki::Schema->SQLFactoryClass()->new_select();
+    $min_revision
+        ->select($min_func)
+        ->from( $Schema->table('PageRevision') )
+        ->where( $Schema->table('PageRevision')->column('page_id'),
+                 '=', $page_t->column('page_id')
+               );
+
+    return $min_revision;
+}
+
 __PACKAGE__->meta()->make_immutable();
 
 1;
@@ -1495,7 +1725,7 @@ Silki::Schema::Wiki - Represents a wiki
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 AUTHOR
 
